@@ -6,6 +6,8 @@ package Net::CLI::Interact::Transport::Base;
 use Moo;
 use MooX::Types::MooseLike::Base qw(InstanceOf);
 
+with "Net::CLI::Interact::Transport::Role::StripControlChars";
+
 BEGIN {
     sub is_win32 { return ($^O eq 'MSWin32') }
 
@@ -127,7 +129,7 @@ the current value of C<timeout>. The default value is 10 seconds.
 
 =head2 irs_re
 
-Returns the Regular Expression reference used to split lines of reponse from
+Returns the Regular Expression reference used to split lines of response from
 the connected device. In the end, you will only receive data from this module
 separated by the C<ors> value (by default a newline character). The C<irs_re>
 is used internally by the module and is:
