@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Serial;
 {
-  $Net::CLI::Interact::Transport::Serial::VERSION = '2.142010';
+  $Net::CLI::Interact::Transport::Serial::VERSION = '2.143070';
 }
 
 use Moo;
@@ -80,8 +80,8 @@ sub runtime_options {
     else {
         return (
             ('--parity=' . $self->connect_options->parity),
-            ('-l ' . $self->connect_options->device),
-            ('-s ' . $self->connect_options->speed),
+            ('-l', $self->connect_options->device),
+            ('-s', $self->connect_options->speed),
             ($self->connect_options->nostop ? '--nostop' : ()),
             @{$self->connect_options->opts},
         );
@@ -102,7 +102,7 @@ Net::CLI::Interact::Transport::Serial - Serial-line based CLI connection
 
 =head1 VERSION
 
-version 2.142010
+version 2.143070
 
 =head1 DESCRIPTION
 
